@@ -23,8 +23,8 @@ def generate_filepath(py_filename, output_folder, start_date, end_date, para_dic
     return filepath
 
 
-def plot_equity_curves(filename, output_folder, start_date, end_date, para_dict, result_df):
+def plot_equity_curves(filename, output_folder, start_date, end_date, para_dict, result_df, settings):
 
-    app = equity_curves.Plot(filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath)
+    app = equity_curves.Plot(filename, output_folder, start_date, end_date, para_dict, result_df, generate_filepath, settings)
 
     return app
\ No newline at end of file
