@@ -74,8 +74,8 @@ class Components:
     def empty_line_chart(self):
         chart_bg = self.chart_bg
         fig_line = px.line()
-        fig_line.update_layout(plot_bgcolor=chart_bg, paper_bgcolor=chart_bg, margin=dict(l=85, r=25, t=30, b=0),
-                               height=450, font={"color": chart_bg})
+        fig_line.update_layout(plot_bgcolor=chart_bg, paper_bgcolor=chart_bg, margin=dict(l=85, r=60, t=30, b=40),
+                               height=340, font={"color": chart_bg})
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor=chart_bg)
 
@@ -129,7 +129,7 @@ class Components:
         per_col_2_1 = []
         per_col_2_2 = []
 
-        keys = ['num_of_trade', 'net_profit', 'net_profit_to_mdd',
+        keys = ['num_of_trade', 'net_profit', 'net_profit_to_mdd','total_commission',
                 'mdd_dollar', 'mdd_pct', 'return_on_capital', 'annualized_return', 'annualized_std', 'annualized_sr',
                 'return_to_bah', 'win_rate', 'cov',
                 'bah_mdd_dollar', 'bah_mdd_pct', 'bah_return', 'bah_annualized_return', 'bah_annualized_std',
@@ -138,6 +138,7 @@ class Components:
         try:
             df['net_profit'] = "{:,}".format(int(round(df['net_profit'], 0)))
             df['net_profit_to_mdd'] = round(df['net_profit_to_mdd'], 2)
+            df['total_commission'] = "{:,}".format(int(round(df['total_commission'] , 0)))
 
             df['mdd_dollar'] = "{:,}".format(int(round(df['mdd_dollar'], 0)))
             df['mdd_pct'] = "{:.0%}".format(df['mdd_pct'] / 100)
@@ -159,6 +160,7 @@ class Components:
         per_col_1_1.append(html.Div('Number of Trade'))
         per_col_1_1.append(html.Div('Net Profit'))
         per_col_1_1.append(html.Div('Net Profit to MDD'))
+        per_col_1_1.append(html.Div('Total Commission'))
         per_col_1_1.append(html.Div(html.Img()))
         per_col_1_1.append(html.Div('MDD Dollar'))
         per_col_1_1.append(html.Div('MDD Percentage'))
@@ -167,16 +169,17 @@ class Components:
         per_col_1_1.append(html.Div('Annualized Std'))
         per_col_1_1.append(html.Div('Annualized Sharp Ratio'))
 
-        for i in range(3):
+        for i in range(4):
             per_col_1_2.append(html.Div(df[keys[i]], style={'text-align': 'center'}))
         per_col_1_2.append(html.Div(html.Img()))
-        for i in range(3, 9):
+        for i in range(4, 10):
             per_col_1_2.append(html.Div(df[keys[i]], style={'text-align': 'center'}))
 
         per_col_2_1.append(html.Div('Return to BaH Ratio'))
         per_col_2_1.append(html.Div('Win Rate'))
         per_col_2_1.append(html.Div('COV'))
         per_col_2_1.append(html.Div(html.Img()))
+        per_col_2_1.append(html.Div(html.Img()))
         per_col_2_1.append(html.Div('BaH MDD Dollar'))
         per_col_2_1.append(html.Div('BaH MDD Percentage'))
         per_col_2_1.append(html.Div('BaH Return'))
@@ -184,10 +187,11 @@ class Components:
         per_col_2_1.append(html.Div('BaH Annualized Std'))
         per_col_2_1.append(html.Div('BaH Annualized Sharp Ratio'))
 
-        for i in range(9, 12):
+        for i in range(10, 13):
             per_col_2_2.append(html.Div(str(df[keys[i]]), style={'text-align': 'center'}))
         per_col_2_2.append(html.Div(html.Img()))
-        for i in range(12, 18):
+        per_col_2_2.append(html.Div(html.Img()))
+        for i in range(13, 19):
             per_col_2_2.append(html.Div(str(df[keys[i]]), style={'text-align': 'center'}))
 
         per_col1.append(dbc.Row([dbc.Col(html.Div(per_col_1_1), width=9),
@@ -302,7 +306,7 @@ class Components:
         fig_line = px.line()
         fig_line.update_xaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
         fig_line.update_yaxes(showline=True, zeroline=False, linecolor='white', gridcolor='rgba(0, 0, 0, 0)')
-        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=350,
+        fig_line.update_layout(plot_bgcolor=self.chart_bg, paper_bgcolor=self.chart_bg, height=340,
                                margin=dict(l=85, r=25, t=10, b=0),
                                showlegend=False,
                                font={"color": "white", 'size': 10.5}, yaxis={'title': 'Equity'},
@@ -427,9 +431,13 @@ class Components:
                                       x=df_chart['date'], y=df_chart['stop_loss'], visible='legendonly',
                                       marker=dict(color='rgba(0, 0, 0, 0)', size=8,
                                                   line=dict(color='blue', width=1.5)), name='stop_loss'), )
+
+        fig_line.update_layout(xaxis_range=[df_chart.iloc[0].date, df_chart.iloc[-1].date])
+
         return fig_line
 
 
+
     def generate_subchart(self,df_chart, element, line_type, line_color):
         if line_type == 'bar':
             fig = go.Figure(
@@ -442,7 +450,7 @@ class Components:
                 go.Scatter(mode='lines', hoverinfo='skip', x=df_chart['date'], y=df_chart[element], showlegend=True,
                            line=dict(color=line_color, width=1.5), name=element), ] )
         fig.update_layout(plot_bgcolor='#1f2c56', paper_bgcolor='#1f2c56', height=60, width=700,
-                          margin=dict(l=85, r=50, t=5, b=10),
+                          margin=dict(l=85, r=50, t=5, b=20),
                           font={"color": "white",'size': 9}, yaxis={'fixedrange': True}, xaxis={'fixedrange': True},
                           bargap=0, )
         fig.update_xaxes(showline=True, zeroline=False, linecolor='#979A9A', gridcolor='#1f2c56', )
